----------------------------
-- Hidden Sphere Settings --
----------------------------
local AddOnName, nsVars = ...
local ss = nsVars.SS
local ssPrivate = ss.pVars.spheres

ssPrivate._f = "SSpheres_frame_"
ssPrivate._v = "SSpheres_frame_"

-- unchangeable values
ssPrivate["general"] = {
  ["SphereSize"] = 150,
  ["resources"] = {
    ["Health"] = {0, {r=0.00,g=1.00,b=0.00,a=1},},
    ["Mana"] = {0, {r=0.00,g=0.00,b=1.00,a=1},},
    ["Absorb"] = {r=0.00,g=1.00,b=0.55,a=0.5},
  },
};

ssPrivate["MapMarker"] = {
  ["size"] = 33,
  ["iconSize"] = 21,
  ["anchorPoint"] = "TOPLEFT",
  ["posX"] = 7,
  ["posY"] = -6,
  ["texture"] = ss.FillTextures.get("alternate", 5),
  ["color"] = {r=1,g=0,b=0,a=1},
  ["trackingBorder"] = {
    ["size"] = 56,
    ["texture"] = "Interface\\Minimap\\MiniMap-TrackingBorder",
  },
};

ssPrivate["layout"] = {
  ["additionalResource"] = {
    ["posX"] = 95,
    ["posY"] = 70,
  },
  ["pet"] = {
    ["posX"] = -95,
    ["posY"] = 70,
  },
  ["config"] = {
    ["frameLevelAdjust"] = 4,
    ["healthSphereButton"] = {
      ["color"] = {r=0,g=1,b=0,a=1},
    },
    ["additionalResourceSphereButton"] = {
      ["color"] = {r=1,g=0,b=0,a=1},
    },
    ["mainResourceSphereButton"] = {
      ["color"] = {r=0,g=0,b=1,a=1},
    },
  },
  ["frameList"] = {
    [1] = "health",
    [2] = "mainResource",
    [3] = "additionalResource",
    [4] = "additionalResource",
  },
};

-- TODO Remove This
ssPrivate["config"] = {
  ["healthSphereButton"] = {
    ["color"] = {r=0,g=1,b=0,a=1},
  },
  ["additionalResourceSphereButton"] = {
    ["color"] = {r=1,g=0,b=0,a=1},
  },
  ["mainResourceSphereButton"] = {
    ["color"] = {r=0,g=0,b=1,a=1},
  },
  ["petSphereButton"] = {
    ["color"] = {r=1,g=0,b=0,a=1},
  },
  ["profileButton"] = {
    ["color"] = {r=1,g=0,b=0,a=1},
  },
};

ssPrivate["textures"] = {
  ["aditionalResource"] = ss.FillTextures.get("split", 1),
  ["gloss"] = ss.SphereTextures:Get("gloss", 3),
  ["mainResourceArtwork"] = ss.SharedMedia:GetArtwork(1, "angel"),
  ["healthArtwork"] = ss.SharedMedia:GetArtwork(1, "demon"),
  ["divider"] = ss.SphereTextures:Get("divider", 1),
  ["mapMarker"] = ss.FillTextures.get("alternate", 5),
};

ssPrivate["font"] = {
  ["general"] = ss.SharedMedia.fontChoices[1],
  ["sphere"] = ss.SharedMedia.fontChoices[2],
};

ssPrivate["fontSize"] = {
  ["sphereSmall"] = 14,
  ["sphereMedium"] = 16,
  ["sphereLarge"] = 28,
};

ssPrivate["fontFlag"] = {
  ["sphere"] = "THINOUTLINE",
};

ssPrivate["SSProfile_Default"] = {
  track = {
    ["additionalResource"] = true,
    ["pet"] = true,
  },
  health = {
    ["general"] = {
      ["size"] = 150,
      ["scale"] = 1,
      ["posX"] = -250,
      ["posY"] = 0,
      ["anchor"] = "BOTTOM",
      ["unit"] = "player",
      ["configName"] = "health",
      ["frameStrata"] = "BACKGROUND",
      ["name"] = "SeamoreSpheres_Health",
    },
    ["animation"]= {
      ["posX"] = 0,
      ["posY"] = 0.07,
      ["alpha"] = 0.3,
      ["camDistance"] = 1.85,
      ["scale"] = 1,
      ["id"] = "pearl",
      ["groupId"] = "orbtacular",
      ["frameLevel"] = 3,
    },
    ["swirl"] = {
      ["id"] = "galaxy",
      ["groupId"] = "swirl",
      ["speed"] = 5,
    },
    ["font"] = {
      [1] = {
        ["show"] = true,
      },
      [2] = {
        ["show"] = true,
      },
    },
    ["textFormat"] = "truncated",
    ["modeSpec"] = "defaultSpec",
    ["mode"] = "default",
    ["modes"] = {
      ["defaultSpec"] = {
        ["default"] = {
          ["fillColor"] = {
            [1] = { 0,  { r=0.78, g=.61, b=0.43, a=1, }, },
          },
          ["swirlColor"] = {
            [1] = { r=0.78, g=.61, b=0.43, a=0.35, },
          },
          ["fontColor"] = {
            [1] = {r=1,g=1,b=1,a=1},
            [2] = {r=1,g=1,b=1,a=1},
          },
          ["fillInfo"] = {
            ["fillGroup"] = "primary",
            ["fillId"] = "moon",
          },
          ["fillTexture"] = {
            [1] = ss.FillTextures.get("primary","moon"),
          },
          ["monitorValue"] = 0,
        },
        ["combat"] = {
          ["fillColor"] = {
            [1] = { 0,  { r=0.000, g=1.000, b=0.000, a=1.00 }, },
          },
          ["swirlColor"] = {
            [1] = { r=1.000, g=0.000, b=0.000, a=0.35 },
          },
          ["fontColor"] = {
            [1] = {r=1,g=1,b=1,a=1},
            [2] = {r=1,g=1,b=1,a=1},
          },
          ["fillInfo"] = {
            ["fillGroup"] = "primary",
            ["fillId"] = "moon",
          },
          ["fillTexture"] = {
            [1] = ss.FillTextures.get("primary","moon"),
          },
          ["monitorValue"] = 0,
        },
      },
    },
  },
  mainResource = {
    ["general"] = {
      ["size"] = 150,
      ["scale"] = 1,
      ["posX"] = 250,
      ["posY"] = 0,
      ["anchor"] = "BOTTOM",
      ["unit"] = "player",
      ["configName"] = "mainResource",
      ["frameStrata"] = "BACKGROUND",
      ["name"] = "SeamoreSpheres_MainResource",
    },
    ["animation"]= {
      ["posX"] = 0,
      ["posY"] = 0.07,
      ["alpha"] = 0.3,
      ["camDistance"] = 1.85,
      ["scale"] = 1,
      ["id"] = "pearl",
      ["groupId"] = "orbtacular",
      ["frameLevel"] = 3,
    },
    ["swirl"] = {
      ["id"] = "galaxy",
      ["groupId"] = "swirl",
      ["speed"] = 5,
    },
    ["font"] = {
      [1] = {
        ["show"] = true,
      },
      [2] = {
        ["show"] = true,
      },
    },
    ["textFormat"] = "truncated",
    ["modeSpec"] = "defaultSpec",
    ["mode"] = "default",
    ["modes"] = {
      ["defaultSpec"] = {
        ["default"] = {
          ["fillColor"] = {
            [1] = { 0,  { r=1.000, g=0.000, b=0.000, a=1 }, },
          },
          ["swirlColor"] = {
            [1] = { r=1.000, g=0.000, b=0.000, a=0.35 },
          },
          ["fontColor"] = {
            [1] = {r=1,g=1,b=1,a=1},
            [2] = {r=1,g=1,b=1,a=1},
          },
          ["fillInfo"] = {
            ["fillGroup"] = "primary",
            ["fillId"] = "moon",
          },
          ["fillTexture"] = {
            [1] = ss.FillTextures.get("primary","moon"),
          },
          ["monitorValue"] = 0,
        },
      },
    },
  },
  additionalResource = {
    ["general"] = {
      ["size"] = 87,
      ["scale"] = 1.724,
      ["posX"] = 375,
      ["posY"] = 125,
      ["anchor"] = "BOTTOM",
      ["show"] = true,
      ["showValue"] = true,
      ["unit"] = "player",
      ["configName"] = "additionalResource",
      ["frameStrata"] = "BACKGROUND",
      ["name"] = "SeamoreSpheres_AdditionalResource",
    },
    ["animation"]= {
      ["posX"] = 0,
      ["posY"] = 0.07,
      ["alpha"] = 0.3,
      ["camDistance"] = 1.85,
      ["scale"] = 1,
      ["id"] = "pearl",
      ["groupId"] = "orbtacular",
      ["frameLevel"] = 3,
    },
    ["swirl"] = {
      ["id"] = "galaxy",
      ["groupId"] = "swirl",
      ["speed"] = 5,
    },
    ["font"] = {
      [1] = {
        ["show"] = true,
      },
      [2] = {
        ["show"] = true,
      },
    },
    ["textFormat"] = "truncated",
    ["modeSpec"] = "defaultSpec",
    ["mode"] = "default",
    ["modes"] = {
      ["defaultSpec"] = {
        ["default"] = {
          ["fillColor"] = {
            [1] = { 0,  { r=1.000, g=0.000, b=0.000, a=1.00 }, },
          },
          ["swirlColor"] = {
            [1] = { r=1.000, g=0.000, b=0.000, a=0.35 },
          },
          ["fontColor"] = {
            [1] = {r=1,g=1,b=1,a=1},
            [2] = {r=1,g=1,b=1,a=1},
          },
          ["fillInfo"] = {
            ["fillGroup"] = "primary",
            ["fillId"] = "moon",
          },
          ["fillTexture"] = {
            [1] = ss.FillTextures.get("primary","moon"),
          },
          ["monitorValue"] = 0,
        },
      },
    },
  },
  pet = {
    ["general"] = {
      ["size"] = 87,
      ["scale"] = 1.724,
      ["posX"] = -375,
      ["posY"] = 125,
      ["anchor"] = "BOTTOM",
      ["show"] = true,
      ["showValue"] = true,
      ["unit"] = "pet",
      ["configName"] = "pet",
      ["frameStrata"] = "BACKGROUND",
      ["name"] = "SeamoreSpheres_PetResource",
    },
    ["animation"]= {
      ["posX"] = 0,
      ["posY"] = 0.07,
      ["alpha"] = 0.3,
      ["camDistance"] = 1.85,
      ["scale"] = 1,
      ["id"] = "pearl",
      ["groupId"] = "orbtacular",
      ["frameLevel"] = 3,
    },
    ["swirl"] = {
      ["id"] = "galaxy",
      ["groupId"] = "swirl",
      ["speed"] = 5,
    },
    ["font"] = {
      [1] = {
        ["show"] = true,
      },
      [2] = {
        ["show"] = true,
      },
    },
    ["textFormat"] = "truncated",
    ["modeSpec"] = "defaultSpec",
    ["mode"] = "default",
    ["modes"] = {
      ["defaultSpec"] = {
        ["default"] = {
          ["fillColor"] = {
            [1] = { 0,  { r=0.67, g=0.83, b=0.45, a=1, }, },
            [2] = { 0,  { r=1.000, g=0.500, b=0.250, a=1 }, },
          },
          ["swirlColor"] = {
            [1] = { r=0.67, g=0.83, b=0.45, a=1, },
          },
          ["fontColor"] = {
            [1] = {r=1,g=1,b=1,a=1},
            [2] = {r=1,g=1,b=1,a=1},
          },
          ["fillInfo"] = {
            ["fillGroup"] = "split",
            ["fillId"] = 1,
          },
          ["fillTexture"] = ss.FillTextures.get("split", 1),
          ["monitorValue"] = 0,
        },
      },
    },
  },
  vehicle = {
    ["general"] = {
      ["size"] = 150,
      ["scale"] = 1,
      ["posX"] = -250,
      ["posY"] = 0,
      ["anchor"] = "BOTTOM",
      ["unit"] = "vehicle",
      ["configName"] = "vehicle",
      ["frameStrata"] = "BACKGROUND",
      ["name"] = "SeamoreSpheres_Vehicle",
    },
    ["animation"]= {
      ["posX"] = 0,
      ["posY"] = 0.07,
      ["alpha"] = 0.3,
      ["camDistance"] = 1.85,
      ["scale"] = 1,
      ["id"] = "pearl",
      ["groupId"] = "orbtacular",
      ["frameLevel"] = 3,
    },
    ["swirl"] = {
      ["id"] = "galaxy",
      ["groupId"] = "swirl",
      ["speed"] = 5,
    },
    ["font"] = {
      [1] = {
        ["show"] = true,
      },
      [2] = {
        ["show"] = true,
      },
    },
    ["textFormat"] = "truncated",
    ["modeSpec"] = "defaultSpec",
    ["mode"] = "default",
    ["modes"] = {
      ["defaultSpec"] = {
        ["default"] = {
          ["fillColor"] = {
            [1] = { 0,  { r=0.67, g=0.83, b=0.45, a=1, }, },
          },
          ["swirlColor"] = {
            [1] = { r=0.67, g=0.83, b=0.45, a=1, },
          },
          ["fontColor"] = {
            [1] = {r=1,g=1,b=1,a=1},
            [2] = {r=1,g=1,b=1,a=1},
          },
          ["fillInfo"] = {
            ["fillGroup"] = "primary",
            ["fillId"] = "moon",
          },
          ["fillTexture"] = {
            [1] = ss.FillTextures.get("primary","moon"),
          },
          ["monitorValue"] = 0,
        },
        ["combat"] = {
          ["fillColor"] = {
            [1] = { 0,  { r=0.67, g=0.83, b=0.45, a=1, }, },
          },
          ["swirlColor"] = {
            [1] = { r=1.000, g=0.000, b=0.000, a=0.35 },
          },
          ["fontColor"] = {
            [1] = {r=1,g=1,b=1,a=1},
            [2] = {r=1,g=1,b=1,a=1},
          },
          ["fillInfo"] = {
            ["fillGroup"] = "primary",
            ["fillId"] = "moon",
          },
          ["fillTexture"] = {
            [1] = ss.FillTextures.get("primary","moon"),
          },
          ["monitorValue"] = 0,
        },
      },
    },
  },
  vehicleResource = {
    ["general"] = {
      ["size"] = 150,
      ["scale"] = 1,
      ["posX"] = 250,
      ["posY"] = 0,
      ["anchor"] = "BOTTOM",
      ["unit"] = "vehicle",
      ["configName"] = "vehicleResource",
      ["frameStrata"] = "BACKGROUND",
      ["name"] = "SeamoreSpheres_VehicleResource",
    },
    ["animation"]= {
      ["posX"] = 0,
      ["posY"] = 0.07,
      ["alpha"] = 0.3,
      ["camDistance"] = 1.85,
      ["scale"] = 1,
      ["id"] = "pearl",
      ["groupId"] = "orbtacular",
      ["frameLevel"] = 3,
    },
    ["swirl"] = {
      ["id"] = "galaxy",
      ["groupId"] = "swirl",
      ["speed"] = 5,
    },
    ["font"] = {
      [1] = {
        ["show"] = true,
      },
      [2] = {
        ["show"] = true,
      },
    },
    ["textFormat"] = "truncated",
    ["modeSpec"] = "defaultSpec",
    ["mode"] = "default",
    ["modes"] = {
      ["defaultSpec"] = {
        ["default"] = {
          ["fillColor"] = {
            [1] = { 0,  { r=1.000, g=0.500, b=0.250, a=1 }, },
          },
          ["swirlColor"] = {
            [1] = { r=1.000, g=0.500, b=0.250, a=1 },
          },
          ["fontColor"] = {
            [1] = {r=1,g=1,b=1,a=1},
            [2] = {r=1,g=1,b=1,a=1},
          },
          ["fillInfo"] = {
            ["fillGroup"] = "primary",
            ["fillId"] = "moon",
          },
          ["fillTexture"] = {
            [1] = ss.FillTextures.get("primary","moon"),
          },
          ["monitorValue"] = 0,
        },
        ["combat"] = {
          ["fillColor"] = {
            [1] = { 0,  { r=1.000, g=0.500, b=0.250, a=1 }, },
          },
          ["swirlColor"] = {
            [1] = { r=1.000, g=0.500, b=0.250, a=1 },
          },
          ["fontColor"] = {
            [1] = {r=1,g=1,b=1,a=1},
            [2] = {r=1,g=1,b=1,a=1},
          },
          ["fillInfo"] = {
            ["fillGroup"] = "primary",
            ["fillId"] = "moon",
          },
          ["fillTexture"] = {
            [1] = ss.FillTextures.get("primary","moon"),
          },
          ["monitorValue"] = 0,
        },
      },
    },
  },
};

-- camD 0.589, x 0, y 0

--[[
--
 -
 obrtacular - dwarf artifact
  cam distance = 0.589
  x = 0
  y = 0
 orbtacular - purple circus
  cam distance = 0.708
  x = 0
  y = -0.06





 -
-- ]]



